searchData={"items":[{"type":"module","title":"ConfluenceLoader","doc":"ConfluenceLoader is an Elixir library for fetching and reading Confluence pages.\n\nIt provides a simple interface to interact with Confluence's REST API and\nconvert pages into a format suitable for use with language models.","ref":"ConfluenceLoader.html"},{"type":"module","title":"Installation - ConfluenceLoader","doc":"Add `confluence_loader` to your list of dependencies in `mix.exs`:\n\n    def deps do\n      [\n        {:confluence_loader, \"~> 0.1.0\"}\n      ]\n    end","ref":"ConfluenceLoader.html#module-installation"},{"type":"module","title":"Basic Usage - ConfluenceLoader","doc":"# Create a client\n    client = ConfluenceLoader.new_client(\n      \"https://your-domain.atlassian.net\",\n      \"your-email@example.com\",\n      \"your-api-token\"\n    )\n\n    # Load all documents\n    {:ok, documents} = ConfluenceLoader.load_documents(client)\n\n    # Load documents from a specific space\n    {:ok, documents} = ConfluenceLoader.load_space_documents(client, \"SPACE_KEY\")\n\n    # Get a specific page\n    {:ok, page} = ConfluenceLoader.get_page(client, \"123456\")","ref":"ConfluenceLoader.html#module-basic-usage"},{"type":"function","title":"ConfluenceLoader.get_page/3","doc":"Get a specific page by ID.","ref":"ConfluenceLoader.html#get_page/3"},{"type":"function","title":"Parameters - ConfluenceLoader.get_page/3","doc":"- client: The Confluence client\n  - page_id: The ID of the page\n  - params: Optional parameters","ref":"ConfluenceLoader.html#get_page/3-parameters"},{"type":"function","title":"ConfluenceLoader.get_pages/2","doc":"Get all pages with optional filtering.","ref":"ConfluenceLoader.html#get_pages/2"},{"type":"function","title":"Parameters - ConfluenceLoader.get_pages/2","doc":"- client: The Confluence client\n  - params: Optional filtering parameters","ref":"ConfluenceLoader.html#get_pages/2-parameters"},{"type":"function","title":"ConfluenceLoader.get_pages_for_label/3","doc":"Get pages for a specific label.","ref":"ConfluenceLoader.html#get_pages_for_label/3"},{"type":"function","title":"Parameters - ConfluenceLoader.get_pages_for_label/3","doc":"- client: The Confluence client\n  - label_id: The ID of the label\n  - params: Optional filtering parameters","ref":"ConfluenceLoader.html#get_pages_for_label/3-parameters"},{"type":"function","title":"ConfluenceLoader.get_pages_in_space/3","doc":"Get pages in a specific space.","ref":"ConfluenceLoader.html#get_pages_in_space/3"},{"type":"function","title":"Parameters - ConfluenceLoader.get_pages_in_space/3","doc":"- client: The Confluence client\n  - space_key: The key of the space (e.g., \"PROJ\", \"TEAM\")\n  - params: Optional filtering parameters","ref":"ConfluenceLoader.html#get_pages_in_space/3-parameters"},{"type":"function","title":"ConfluenceLoader.load_documents/2","doc":"Load all pages from Confluence as documents.","ref":"ConfluenceLoader.html#load_documents/2"},{"type":"function","title":"Parameters - ConfluenceLoader.load_documents/2","doc":"- client: The Confluence client\n  - params: Optional filtering parameters","ref":"ConfluenceLoader.html#load_documents/2-parameters"},{"type":"function","title":"ConfluenceLoader.load_documents_since/4","doc":"Load documents from a specific space created at or after a given timestamp.\n\nThis method filters pages by namespace (space) and creation timestamp, useful for\nincremental updates or getting only recent content changes.","ref":"ConfluenceLoader.html#load_documents_since/4"},{"type":"function","title":"Parameters - ConfluenceLoader.load_documents_since/4","doc":"- client: The Confluence client\n  - space_key: The key of the space (e.g., \"PROJ\", \"TEAM\")\n  - since_timestamp: DateTime struct or ISO 8601 string (e.g., \"2024-01-01T00:00:00Z\")\n  - params: Optional filtering parameters","ref":"ConfluenceLoader.html#load_documents_since/4-parameters"},{"type":"function","title":"ConfluenceLoader.load_space_documents/3","doc":"Load pages from a specific space as documents.","ref":"ConfluenceLoader.html#load_space_documents/3"},{"type":"function","title":"Parameters - ConfluenceLoader.load_space_documents/3","doc":"- client: The Confluence client\n  - space_key: The key of the space (e.g., \"PROJ\", \"TEAM\")\n  - params: Optional filtering parameters","ref":"ConfluenceLoader.html#load_space_documents/3-parameters"},{"type":"function","title":"ConfluenceLoader.new_client/4","doc":"Creates a new Confluence client.","ref":"ConfluenceLoader.html#new_client/4"},{"type":"function","title":"Parameters - ConfluenceLoader.new_client/4","doc":"- base_url: The base URL of your Confluence instance\n  - username: Your Atlassian username (email)\n  - api_token: Your Atlassian API token\n  - opts: Optional configuration (e.g., timeout)","ref":"ConfluenceLoader.html#new_client/4-parameters"},{"type":"function","title":"ConfluenceLoader.stream_space_documents/3","doc":"Stream documents from a specific space in batches of 4.\n\nThis function returns a Stream that yields batches of 4 documents at a time\nuntil all documents from the space have been processed. It's memory efficient\nas it doesn't load all documents into memory at once.","ref":"ConfluenceLoader.html#stream_space_documents/3"},{"type":"function","title":"Parameters - ConfluenceLoader.stream_space_documents/3","doc":"- client: The Confluence client\n  - space_key: The key of the space (e.g., \"PROJ\", \"TEAM\") or numeric space ID\n  - params: Optional parameters for filtering (body_format, etc.)","ref":"ConfluenceLoader.html#stream_space_documents/3-parameters"},{"type":"function","title":"Examples - ConfluenceLoader.stream_space_documents/3","doc":"# Stream and process documents in batches of 4\n    client\n    |> ConfluenceLoader.stream_space_documents(\"PROJ\")\n    |> Enum.each(fn batch ->\n      IO.puts(\"Processing batch of #{length(batch)} documents\")\n      Enum.each(batch, fn doc -> IO.puts(\"  - #{doc.metadata.title}\") end)\n    end)","ref":"ConfluenceLoader.html#stream_space_documents/3-examples"},{"type":"module","title":"ConfluenceLoader.Client","doc":"HTTP client for interacting with the Confluence REST API.\n\nThis module handles authentication and request formatting for the Confluence API.\nIt supports both cloud and server instances of Confluence.","ref":"ConfluenceLoader.Client.html"},{"type":"module","title":"Configuration - ConfluenceLoader.Client","doc":"The client requires:\n- `base_url`: Your Confluence instance URL (e.g., \"https://example.atlassian.net\")\n- `username`: Your email address (for cloud) or username (for server)\n- `api_token`: Your API token (for cloud) or password (for server)","ref":"ConfluenceLoader.Client.html#module-configuration"},{"type":"module","title":"Options - ConfluenceLoader.Client","doc":"- `:api_base_path` - The base path for the API (default: \"/wiki/api/v2\")\n- `:timeout` - Request timeout in milliseconds (default: 30_000)\n- `:recv_timeout` - Receive timeout in milliseconds (default: 30_000)","ref":"ConfluenceLoader.Client.html#module-options"},{"type":"module","title":"Examples - ConfluenceLoader.Client","doc":"# For Confluence Cloud\n    client = ConfluenceLoader.Client.new(\"https://example.atlassian.net\", \"user@example.com\", \"api_token\")\n    %ConfluenceLoader.Client{...}\n\n    # For Confluence Server with custom API path\n    client = ConfluenceLoader.Client.new(\"https://example.atlassian.net\", \"user@example.com\", \"api_token\", api_base_path: \"/api/v2\")\n    %ConfluenceLoader.Client{...}","ref":"ConfluenceLoader.Client.html#module-examples"},{"type":"function","title":"ConfluenceLoader.Client.get/3","doc":"Makes a GET request to the Confluence API.","ref":"ConfluenceLoader.Client.html#get/3"},{"type":"function","title":"ConfluenceLoader.Client.new/4","doc":"Creates a new Confluence client.","ref":"ConfluenceLoader.Client.html#new/4"},{"type":"function","title":"Parameters - ConfluenceLoader.Client.new/4","doc":"- base_url: The base URL of your Confluence instance (e.g., \"https://your-domain.atlassian.net\")\n  - username: Your Atlassian username (email)\n  - api_token: Your Atlassian API token\n  - opts: Optional keyword list with:\n    - timeout: Request timeout in milliseconds (default: 30000)\n    - api_base_path: Custom API base path (default: \"/wiki/api/v2\")","ref":"ConfluenceLoader.Client.html#new/4-parameters"},{"type":"function","title":"Examples - ConfluenceLoader.Client.new/4","doc":"iex> client = ConfluenceLoader.Client.new(\"https://example.atlassian.net\", \"user@example.com\", \"api_token\")\n    %ConfluenceLoader.Client{...}\n\n    # For Confluence Cloud with different API path\n    iex> client = ConfluenceLoader.Client.new(\"https://example.atlassian.net\", \"user@example.com\", \"api_token\", api_base_path: \"/api/v2\")\n    %ConfluenceLoader.Client{...}","ref":"ConfluenceLoader.Client.html#new/4-examples"},{"type":"type","title":"ConfluenceLoader.Client.t/0","doc":"","ref":"ConfluenceLoader.Client.html#t:t/0"},{"type":"module","title":"ConfluenceLoader.Document","doc":"Document struct that represents a Confluence page in a format similar to llama-index documents.","ref":"ConfluenceLoader.Document.html"},{"type":"function","title":"ConfluenceLoader.Document.format_for_llm/1","doc":"Returns a formatted string representation of the document suitable for LLM consumption.","ref":"ConfluenceLoader.Document.html#format_for_llm/1"},{"type":"function","title":"Examples - ConfluenceLoader.Document.format_for_llm/1","doc":"iex> doc = ConfluenceLoader.Document.new(\"123\", \"Content here\", %{title: \"My Page\", space_id: \"SPACE1\"})\n    iex> ConfluenceLoader.Document.format_for_llm(doc)","ref":"ConfluenceLoader.Document.html#format_for_llm/1-examples"},{"type":"function","title":"ConfluenceLoader.Document.from_map/1","doc":"Creates a Document from a map.","ref":"ConfluenceLoader.Document.html#from_map/1"},{"type":"function","title":"Examples - ConfluenceLoader.Document.from_map/1","doc":"iex> ConfluenceLoader.Document.from_map(%{id: \"123\", text: \"Content\", metadata: %{title: \"Page\"}})\n    {:ok, %ConfluenceLoader.Document{id: \"123\", text: \"Content\", metadata: %{title: \"Page\"}}}","ref":"ConfluenceLoader.Document.html#from_map/1-examples"},{"type":"function","title":"ConfluenceLoader.Document.new/3","doc":"Creates a new Document.","ref":"ConfluenceLoader.Document.html#new/3"},{"type":"function","title":"Parameters - ConfluenceLoader.Document.new/3","doc":"- id: The unique identifier of the document\n  - text: The text content of the document\n  - metadata: Optional metadata map","ref":"ConfluenceLoader.Document.html#new/3-parameters"},{"type":"function","title":"Examples - ConfluenceLoader.Document.new/3","doc":"iex> doc = ConfluenceLoader.Document.new(\"123\", \"This is the content\", %{title: \"My Page\"})\n    %ConfluenceLoader.Document{id: \"123\", text: \"This is the content\", metadata: %{title: \"My Page\"}}","ref":"ConfluenceLoader.Document.html#new/3-examples"},{"type":"type","title":"ConfluenceLoader.Document.t/0","doc":"","ref":"ConfluenceLoader.Document.html#t:t/0"},{"type":"function","title":"ConfluenceLoader.Document.to_map/1","doc":"Converts the document to a map format suitable for JSON serialization.","ref":"ConfluenceLoader.Document.html#to_map/1"},{"type":"function","title":"Examples - ConfluenceLoader.Document.to_map/1","doc":"iex> doc = ConfluenceLoader.Document.new(\"123\", \"Content\", %{title: \"Page\"})\n    iex> ConfluenceLoader.Document.to_map(doc)\n    %{id: \"123\", text: \"Content\", metadata: %{title: \"Page\"}}","ref":"ConfluenceLoader.Document.html#to_map/1-examples"},{"type":"module","title":"ConfluenceLoader.Pages","doc":"Functions for fetching and processing Confluence pages.","ref":"ConfluenceLoader.Pages.html"},{"type":"function","title":"ConfluenceLoader.Pages.get_page/3","doc":"Get a specific page by ID.","ref":"ConfluenceLoader.Pages.html#get_page/3"},{"type":"function","title":"Parameters - ConfluenceLoader.Pages.get_page/3","doc":"- client: The Confluence client\n  - page_id: The ID of the page to retrieve\n  - params: Optional parameters (e.g., body_format)","ref":"ConfluenceLoader.Pages.html#get_page/3-parameters"},{"type":"function","title":"Examples - ConfluenceLoader.Pages.get_page/3","doc":"iex> {:ok, page} = ConfluenceLoader.Pages.get_page(client, \"123456\")","ref":"ConfluenceLoader.Pages.html#get_page/3-examples"},{"type":"function","title":"ConfluenceLoader.Pages.get_pages/2","doc":"Get all pages with optional filtering.","ref":"ConfluenceLoader.Pages.html#get_pages/2"},{"type":"function","title":"Parameters - ConfluenceLoader.Pages.get_pages/2","doc":"- client: The Confluence client\n  - params: Optional parameters for filtering pages","ref":"ConfluenceLoader.Pages.html#get_pages/2-parameters"},{"type":"function","title":"Examples - ConfluenceLoader.Pages.get_pages/2","doc":"iex> {:ok, pages} = ConfluenceLoader.Pages.get_pages(client, %{space_id: [123], limit: 10})","ref":"ConfluenceLoader.Pages.html#get_pages/2-examples"},{"type":"function","title":"ConfluenceLoader.Pages.get_pages_for_label/3","doc":"Get pages for a specific label.","ref":"ConfluenceLoader.Pages.html#get_pages_for_label/3"},{"type":"function","title":"Parameters - ConfluenceLoader.Pages.get_pages_for_label/3","doc":"- client: The Confluence client\n  - label_id: The ID of the label\n  - params: Optional parameters for filtering","ref":"ConfluenceLoader.Pages.html#get_pages_for_label/3-parameters"},{"type":"function","title":"Examples - ConfluenceLoader.Pages.get_pages_for_label/3","doc":"iex> {:ok, pages} = ConfluenceLoader.Pages.get_pages_for_label(client, \"456\", %{limit: 10})","ref":"ConfluenceLoader.Pages.html#get_pages_for_label/3-examples"},{"type":"function","title":"ConfluenceLoader.Pages.get_pages_in_space/3","doc":"Get pages in a specific space.","ref":"ConfluenceLoader.Pages.html#get_pages_in_space/3"},{"type":"function","title":"Parameters - ConfluenceLoader.Pages.get_pages_in_space/3","doc":"- client: The Confluence client\n  - space_key: The key of the space (e.g., \"PROJ\", \"TEAM\") or numeric space ID\n  - params: Optional parameters for filtering","ref":"ConfluenceLoader.Pages.html#get_pages_in_space/3-parameters"},{"type":"function","title":"Examples - ConfluenceLoader.Pages.get_pages_in_space/3","doc":"iex> {:ok, pages} = ConfluenceLoader.Pages.get_pages_in_space(client, \"PROJ\", %{limit: 20})","ref":"ConfluenceLoader.Pages.html#get_pages_in_space/3-examples"},{"type":"function","title":"ConfluenceLoader.Pages.load_documents/2","doc":"Load all pages from Confluence and convert them to Document format.\nThis function mimics the behavior of the Python llama-index-readers-confluence library.","ref":"ConfluenceLoader.Pages.html#load_documents/2"},{"type":"function","title":"Parameters - ConfluenceLoader.Pages.load_documents/2","doc":"- client: The Confluence client\n  - params: Optional parameters for filtering pages","ref":"ConfluenceLoader.Pages.html#load_documents/2-parameters"},{"type":"function","title":"Examples - ConfluenceLoader.Pages.load_documents/2","doc":"iex> {:ok, documents} = ConfluenceLoader.Pages.load_documents(client, %{space_id: [123]})","ref":"ConfluenceLoader.Pages.html#load_documents/2-examples"},{"type":"function","title":"ConfluenceLoader.Pages.load_documents_since/4","doc":"Load documents from a specific space created at or after a given timestamp.\n\nThis method filters pages by namespace (space) and creation timestamp. Since the\nConfluence API doesn't directly support timestamp filtering, this method fetches\nall pages from the space and filters them client-side.","ref":"ConfluenceLoader.Pages.html#load_documents_since/4"},{"type":"function","title":"Parameters - ConfluenceLoader.Pages.load_documents_since/4","doc":"- client: The Confluence client\n  - space_key: The key of the space (e.g., \"PROJ\", \"TEAM\") or numeric space ID\n  - since_timestamp: DateTime struct or ISO 8601 string (e.g., \"2024-01-01T00:00:00Z\")\n  - params: Optional parameters for filtering (limit, body_format, etc.)","ref":"ConfluenceLoader.Pages.html#load_documents_since/4-parameters"},{"type":"function","title":"Examples - ConfluenceLoader.Pages.load_documents_since/4","doc":"# Using DateTime\n    {:ok, since_date} = DateTime.new(~D[2024-01-01], ~T[00:00:00], \"Etc/UTC\")\n    {:ok, documents} = ConfluenceLoader.Pages.load_documents_since(client, \"PROJ\", since_date)\n\n    # Using ISO string\n    {:ok, documents} = ConfluenceLoader.Pages.load_documents_since(client, \"PROJ\", \"2024-01-01T00:00:00Z\")\n\n    # With additional parameters\n    {:ok, documents} = ConfluenceLoader.Pages.load_documents_since(client, \"PROJ\", since_date, %{limit: 50})","ref":"ConfluenceLoader.Pages.html#load_documents_since/4-examples"},{"type":"function","title":"ConfluenceLoader.Pages.load_space_documents/3","doc":"Load pages from a specific space and convert them to Document format.","ref":"ConfluenceLoader.Pages.html#load_space_documents/3"},{"type":"function","title":"Parameters - ConfluenceLoader.Pages.load_space_documents/3","doc":"- client: The Confluence client\n  - space_key: The key of the space (e.g., \"PROJ\", \"TEAM\") or numeric space ID\n  - params: Optional parameters for filtering","ref":"ConfluenceLoader.Pages.html#load_space_documents/3-parameters"},{"type":"function","title":"Examples - ConfluenceLoader.Pages.load_space_documents/3","doc":"iex> {:ok, documents} = ConfluenceLoader.Pages.load_space_documents(client, \"PROJ\")","ref":"ConfluenceLoader.Pages.html#load_space_documents/3-examples"},{"type":"type","title":"ConfluenceLoader.Pages.page_params/0","doc":"","ref":"ConfluenceLoader.Pages.html#t:page_params/0"},{"type":"function","title":"ConfluenceLoader.Pages.page_to_document/1","doc":"Convert a page response to a Document struct.\n\nThis is useful when you fetch a page directly and want to convert it to a Document.","ref":"ConfluenceLoader.Pages.html#page_to_document/1"},{"type":"function","title":"Parameters - ConfluenceLoader.Pages.page_to_document/1","doc":"- page: The page response from the API","ref":"ConfluenceLoader.Pages.html#page_to_document/1-parameters"},{"type":"function","title":"Examples - ConfluenceLoader.Pages.page_to_document/1","doc":"iex> {:ok, page} = ConfluenceLoader.get_page(client, \"123\", %{body_format: \"storage\"})\n    iex> doc = ConfluenceLoader.Pages.page_to_document(page)","ref":"ConfluenceLoader.Pages.html#page_to_document/1-examples"},{"type":"function","title":"ConfluenceLoader.Pages.stream_space_documents/3","doc":"Stream documents from a specific space in batches of 4.\n\nThis function returns a Stream that yields batches of 4 documents at a time\nuntil all documents from the space have been processed. It's memory efficient\nas it doesn't load all documents into memory at once.","ref":"ConfluenceLoader.Pages.html#stream_space_documents/3"},{"type":"function","title":"Parameters - ConfluenceLoader.Pages.stream_space_documents/3","doc":"- client: The Confluence client\n  - space_key: The key of the space (e.g., \"PROJ\", \"TEAM\") or numeric space ID\n  - params: Optional parameters for filtering (body_format, etc.)","ref":"ConfluenceLoader.Pages.html#stream_space_documents/3-parameters"},{"type":"function","title":"Examples - ConfluenceLoader.Pages.stream_space_documents/3","doc":"# Stream and process documents in batches of 4\n    client\n    |> ConfluenceLoader.Pages.stream_space_documents(\"PROJ\")\n    |> Enum.each(fn batch ->\n      IO.puts(\"Processing batch of #{length(batch)} documents\")\n      Enum.each(batch, fn doc -> IO.puts(\"  - #{doc.metadata.title}\") end)\n    end)\n\n    # With async processing using Task.async_stream\n    client\n    |> ConfluenceLoader.Pages.stream_space_documents(\"PROJ\")\n    |> Task.async_stream(fn batch ->\n      # Process each batch concurrently\n      Enum.map(batch, &process_document/1)\n    end, max_concurrency: 2)\n    |> Enum.to_list()","ref":"ConfluenceLoader.Pages.html#stream_space_documents/3-examples"},{"type":"extras","title":"ConfluenceLoader","doc":"# ConfluenceLoader\n\nAn Elixir library for fetching and reading Confluence pages, inspired by the Python llama-index-readers-confluence library.","ref":"readme.html"},{"type":"extras","title":"Features - ConfluenceLoader","doc":"- Fetch pages from Confluence Cloud and Server instances\n- Support for both REST API v1 and v2\n- Convert Confluence pages to a document format suitable for LLMs\n- Pagination support for large result sets\n- Flexible authentication (API tokens for Cloud, username/password for Server)","ref":"readme.html#features"},{"type":"extras","title":"Installation - ConfluenceLoader","doc":"Add `confluence_loader` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:confluence_loader, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - ConfluenceLoader","doc":"You'll need:\n- Your Confluence instance URL (e.g., `https://your-domain.atlassian.net`)\n- Authentication credentials:\n  - For Confluence Cloud: Email address and API token\n  - For Confluence Server: Username and password","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - ConfluenceLoader","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Creating a Client - ConfluenceLoader","doc":"```elixir\n# For Confluence Cloud (default)\nclient = ConfluenceLoader.new_client(\n  \"https://your-domain.atlassian.net\",\n  \"your-email@example.com\",\n  \"your-api-token\"\n)\n\n# For Confluence Server with custom API path\nclient = ConfluenceLoader.new_client(\n  \"https://confluence.company.com\",\n  \"username\",\n  \"password\",\n  api_base_path: \"/rest/api\"  # v1 API path\n)\n```","ref":"readme.html#creating-a-client"},{"type":"extras","title":"Loading Documents - ConfluenceLoader","doc":"```elixir\n# Load all pages as documents\n{:ok, documents} = ConfluenceLoader.load_documents(client)\n\n# Load pages from a specific space\n{:ok, documents} = ConfluenceLoader.load_space_documents(client, \"PROJ\")\n\n# Load with specific parameters\n{:ok, documents} = ConfluenceLoader.load_documents(client, %{\n  space_id: [\"123\", \"456\"],  # Multiple space IDs\n  limit: 50,                 # Number of pages per request\n  status: \"current\",         # Page status\n  body_format: \"storage\"     # Format of the content body\n})\n\n# Load documents created since a specific timestamp\n{:ok, since_date} = DateTime.new(~D[2024-01-01], ~T[00:00:00], \"Etc/UTC\")\n{:ok, recent_docs} = ConfluenceLoader.load_documents_since(client, \"PROJ\", since_date)\n\n# Or using an ISO timestamp string\n{:ok, recent_docs} = ConfluenceLoader.load_documents_since(client, \"PROJ\", \"2024-01-01T00:00:00Z\")\n```","ref":"readme.html#loading-documents"},{"type":"extras","title":"Document Structure - ConfluenceLoader","doc":"Each document contains:\n- `id`: The page ID\n- `text`: The page content (HTML stripped)\n- `metadata`: Additional information including:\n  - `title`: Page title\n  - `space_id`: Space ID\n  - `space_key`: Space key\n  - `status`: Page status\n  - `created_at`: Creation timestamp\n  - `updated_at`: Last update timestamp\n  - `url`: Web URL of the page\n  - `parent_id`: Parent page ID (if applicable)","ref":"readme.html#document-structure"},{"type":"extras","title":"Working with Documents - ConfluenceLoader","doc":"```elixir\n# Load documents\n{:ok, documents} = ConfluenceLoader.load_documents(client)\n\n# Access document properties\nEnum.each(documents, fn doc ->\n  IO.puts(\"Title: #{doc.metadata.title}\")\n  IO.puts(\"Content: #{String.slice(doc.text, 0, 100)}...\")\n  \n  # Format for LLM consumption\n  formatted = ConfluenceLoader.Document.format_for_llm(doc)\n  IO.puts(formatted)\nend)\n```","ref":"readme.html#working-with-documents"},{"type":"extras","title":"Timestamp-Based Filtering - ConfluenceLoader","doc":"Load documents from a specific space that were created at or after a given timestamp. This is useful for incremental updates or processing only recent content changes:\n\n```elixir\n# Using DateTime struct\n{:ok, since_date} = DateTime.new(~D[2024-01-01], ~T[00:00:00], \"Etc/UTC\")\n{:ok, recent_docs} = ConfluenceLoader.load_documents_since(client, \"PROJ\", since_date)\n\n# Using ISO 8601 timestamp string\n{:ok, recent_docs} = ConfluenceLoader.load_documents_since(client, \"PROJ\", \"2024-01-01T00:00:00Z\")\n\n# With additional parameters\n{:ok, recent_docs} = ConfluenceLoader.load_documents_since(client, \"PROJ\", since_date, %{limit: 50})\n\n# Load documents from the last 30 days\nthirty_days_ago = DateTime.utc_now() |> DateTime.add(-30, :day)\n{:ok, recent_docs} = ConfluenceLoader.load_documents_since(client, \"SPACE_KEY\", thirty_days_ago)\n```","ref":"readme.html#timestamp-based-filtering"},{"type":"extras","title":"Low-Level API Access - ConfluenceLoader","doc":"You can also use the lower-level API functions directly:\n\n```elixir\n# Get pages with specific parameters\n{:ok, response} = ConfluenceLoader.get_pages(client)\n\n# Get pages with query parameters\n{:ok, response} = ConfluenceLoader.get_pages(client, %{\n  space_id: [\"123\"],\n  limit: 25,\n  sort: \"-created-date\"\n})\n\n# Get a specific page\n{:ok, page} = ConfluenceLoader.get_page(client, \"page_id\")\n\n# Get pages in a space\n{:ok, response} = ConfluenceLoader.get_pages_in_space(client, \"PROJ\")\n\n# Get pages by label\n{:ok, response} = ConfluenceLoader.get_pages_for_label(client, \"label_id\")\n```","ref":"readme.html#low-level-api-access"},{"type":"extras","title":"Pagination - ConfluenceLoader","doc":"The library handles pagination automatically when using `load_documents` functions. For manual pagination with the low-level API:\n\n```elixir\n# Create client\nclient = ConfluenceLoader.new_client(\n  \"https://your-domain.atlassian.net\",\n  \"email@example.com\",\n  \"api-token\"\n)\n\n# Function to fetch all pages\ndef fetch_all_pages(client, cursor \\\\ nil, accumulated \\\\ []) do\n  params = %{limit: 25}\n  params = if cursor, do: Map.put(params, :cursor, cursor), else: params\n  \n  case ConfluenceLoader.get_pages(client, params) do\n    {:ok, response} ->\n      pages = response[\"results\"] || []\n      accumulated = accumulated ++ pages\n      \n      case response[\"_links\"][\"next\"] do\n        nil -> \n          {:ok, accumulated}\n        _ ->\n          # Extract cursor from next link\n          alias ConfluenceLoader.Pages\n          next_cursor = Pages.extract_cursor_from_next_link(response)\n          fetch_all_pages(client, next_cursor, accumulated)\n      end\n      \n    {:error, reason} ->\n      {:error, reason}\n  end\nend\n\n# Use it\n{:ok, first_page} = ConfluenceLoader.get_pages(client, %{limit: 25})\n```","ref":"readme.html#pagination"},{"type":"extras","title":"Testing - ConfluenceLoader","doc":"The library includes comprehensive test coverage using Bypass for mocking HTTP requests:\n\n```bash\nmix test\n```","ref":"readme.html#testing"},{"type":"extras","title":"Contributing - ConfluenceLoader","doc":"1. Fork the repository\n2. Create your feature branch (`git checkout -b feature/my-new-feature`)\n3. Commit your changes (`git commit -am 'Add some feature'`)\n4. Push to the branch (`git push origin feature/my-new-feature`)\n5. Create a new Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"License - ConfluenceLoader","doc":"This project is licensed under the MIT License - see the LICENSE file for details.","ref":"readme.html#license"},{"type":"extras","title":"Acknowledgments - ConfluenceLoader","doc":"This library is inspired by the Python [llama-index-readers-confluence](https://pypi.org/project/llama-index-readers-confluence/) library and provides similar functionality for the Elixir ecosystem.","ref":"readme.html#acknowledgments"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}